@@ -18,7 +18,7 @@ import logging as log
 import os
 from typing import List
 
-from hspylib.core.tools.preconditions import check_argument
+from hspylib.core.preconditions import check_argument
 from requests.structures import CaseInsensitiveDict
 
 from firebase.core.agent_config import AgentConfig
